==> silk-1.1.3.tar.gz: silk-1.1.3/src/pysilk/plugin.py <==
#######################################################################
# Copyright (C) 2008 by Carnegie Mellon University.
#
# @OPENSOURCE_HEADER_START@
#
# Use of the SILK system and related source code is subject to the terms
# of the following licenses:
#
# GNU Public License (GPL) Rights pursuant to Version 2, June 1991
# Government Purpose License Rights (GPLR) pursuant to DFARS 252.225-7013
#
# NO WARRANTY
#
# ANY INFORMATION, MATERIALS, SERVICES, INTELLECTUAL PROPERTY OR OTHER
# PROPERTY OR RIGHTS GRANTED OR PROVIDED BY CARNEGIE MELLON UNIVERSITY
# PURSUANT TO THIS LICENSE (HEREINAFTER THE "DELIVERABLES") ARE ON AN
# "AS-IS" BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY
# KIND, EITHER EXPRESS OR IMPLIED AS TO ANY MATTER INCLUDING, BUT NOT
# LIMITED TO, WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE,
# MERCHANTABILITY, INFORMATIONAL CONTENT, NONINFRINGEMENT, OR ERROR-FREE
# OPERATION. CARNEGIE MELLON UNIVERSITY SHALL NOT BE LIABLE FOR INDIRECT,
# SPECIAL OR CONSEQUENTIAL DAMAGES, SUCH AS LOSS OF PROFITS OR INABILITY
# TO USE SAID INTELLECTUAL PROPERTY, UNDER THIS LICENSE, REGARDLESS OF
# WHETHER SUCH PARTY WAS AWARE OF THE POSSIBILITY OF SUCH DAMAGES.
# LICENSEE AGREES THAT IT WILL NOT MAKE ANY WARRANTY ON BEHALF OF
# CARNEGIE MELLON UNIVERSITY, EXPRESS OR IMPLIED, TO ANY PERSON
# CONCERNING THE APPLICATION OF OR THE RESULTS TO BE OBTAINED WITH THE
# DELIVERABLES UNDER THIS LICENSE.
#
# Licensee hereby agrees to defend, indemnify, and hold harmless Carnegie
# Mellon University, its trustees, officers, employees, and agents from
# all claims or demands made against them (and any related losses,
# expenses, or attorney's fees) arising out of, or relating to Licensee's
# and/or its sub licensees' negligent use or willful misuse of or
# negligent conduct or willful misconduct regarding the Software,
# facilities, or other rights or assistance granted by Carnegie Mellon
# University under this License, including, but not limited to, any
# claims of product liability, personal injury, death, damage to
# property, or violation of any laws or regulations.
#
# Carnegie Mellon University Software Engineering Institute authored
# documents are sponsored by the U.S. Department of Defense under
# Contract F19628-00-C-0003. Carnegie Mellon University retains
# copyrights in all material produced under this contract. The U.S.
# Government retains a non-exclusive, royalty-free license to publish or
# reproduce these documents, or allow others to do so, for U.S.
# Government purposes only pursuant to the copyright license under the
# contract clause at 252.227.7013.
#
# @OPENSOURCE_HEADER_END@
#
#######################################################################

#######################################################################
# $SiLK: plugin.py 11782 2008-06-11 16:28:15Z mwd $
#######################################################################

##########################################################################
# Plugin-related code

import inspect

_plugin_data = []
_plugin_fields = {'field_len': int,
                  'rec_to_text': 1,
                  'bin_len': int,
                  'rec_to_bin': 1,
                  'bin_to_text': 1}

_plugin_reqs = {'cut':  ['name', 'field_len', 'rec_to_text'],
                'sort': ['name', 'bin_len', 'rec_to_bin'],
                'uniq': ['name', 'field_len', 'bin_len', 
                         'rec_to_bin', 'bin_to_text']}


def _get_plugin_data(plugin_type):
    data = []
    reqs = _plugin_reqs[plugin_type]
    for (i, field) in enumerate(_plugin_data):
        values = [field[x] for x in reqs if x in field]
        if len(values) == len(reqs):
            data.append(tuple(values))
    if not data:
        raise RuntimeError("No valid fields for %s Python plugin" % 
                           plugin_type)
    return data

def _register_plugin_field(name, **kwds):
    global _plugin_data

    if not isinstance(name, str):
        raise TypeError("Name must be a string")

    for val in _plugin_data:
        if val['name'] == name:
            raise ValueError("A field '%s' has already been registered", name)

    for (kwd, val) in kwds.iteritems():
        if kwd not in _plugin_fields:
            raise ValueError("Illegal argument name '%s'" % kwd)
        field_spec = _plugin_fields[kwd]
        if isinstance(field_spec, type):
            if not isinstance(val, field_spec):
                raise TypeError("Argument '%s' must be of type %s" %
                                (kwd, field_spec))
        elif not callable(val):
            raise TypeError("Argument '%s' must be a function of %d arguments"
                            % (kwd, field_spec))

    kwds['name'] = name
    _plugin_data.append(kwds)


import sys

programname = None

def _no_traceback_exception(t, value, traceback):
    global programname
    t = str(t).split('.')[-1]
    sys.stderr.write(programname + ": " + t + ": " + str(value) + "\n")

def _set_programname(name):
    global programname
    programname = name

sys.excepthook = _no_traceback_exception

==> silk-1.1.9.tar.gz: silk-1.1.9/src/pysilk/plugin.py <==
#######################################################################
# Copyright (C) 2008, 2009 by Carnegie Mellon University.
#
# @OPENSOURCE_HEADER_START@
#
# Use of the SILK system and related source code is subject to the terms
# of the following licenses:
#
# GNU Public License (GPL) Rights pursuant to Version 2, June 1991
# Government Purpose License Rights (GPLR) pursuant to DFARS 252.225-7013
#
# NO WARRANTY
#
# ANY INFORMATION, MATERIALS, SERVICES, INTELLECTUAL PROPERTY OR OTHER
# PROPERTY OR RIGHTS GRANTED OR PROVIDED BY CARNEGIE MELLON UNIVERSITY
# PURSUANT TO THIS LICENSE (HEREINAFTER THE "DELIVERABLES") ARE ON AN
# "AS-IS" BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY
# KIND, EITHER EXPRESS OR IMPLIED AS TO ANY MATTER INCLUDING, BUT NOT
# LIMITED TO, WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE,
# MERCHANTABILITY, INFORMATIONAL CONTENT, NONINFRINGEMENT, OR ERROR-FREE
# OPERATION. CARNEGIE MELLON UNIVERSITY SHALL NOT BE LIABLE FOR INDIRECT,
# SPECIAL OR CONSEQUENTIAL DAMAGES, SUCH AS LOSS OF PROFITS OR INABILITY
# TO USE SAID INTELLECTUAL PROPERTY, UNDER THIS LICENSE, REGARDLESS OF
# WHETHER SUCH PARTY WAS AWARE OF THE POSSIBILITY OF SUCH DAMAGES.
# LICENSEE AGREES THAT IT WILL NOT MAKE ANY WARRANTY ON BEHALF OF
# CARNEGIE MELLON UNIVERSITY, EXPRESS OR IMPLIED, TO ANY PERSON
# CONCERNING THE APPLICATION OF OR THE RESULTS TO BE OBTAINED WITH THE
# DELIVERABLES UNDER THIS LICENSE.
#
# Licensee hereby agrees to defend, indemnify, and hold harmless Carnegie
# Mellon University, its trustees, officers, employees, and agents from
# all claims or demands made against them (and any related losses,
# expenses, or attorney's fees) arising out of, or relating to Licensee's
# and/or its sub licensees' negligent use or willful misuse of or
# negligent conduct or willful misconduct regarding the Software,
# facilities, or other rights or assistance granted by Carnegie Mellon
# University under this License, including, but not limited to, any
# claims of product liability, personal injury, death, damage to
# property, or violation of any laws or regulations.
#
# Carnegie Mellon University Software Engineering Institute authored
# documents are sponsored by the U.S. Department of Defense under
# Contract F19628-00-C-0003. Carnegie Mellon University retains
# copyrights in all material produced under this contract. The U.S.
# Government retains a non-exclusive, royalty-free license to publish or
# reproduce these documents, or allow others to do so, for U.S.
# Government purposes only pursuant to the copyright license under the
# contract clause at 252.227.7013.
#
# @OPENSOURCE_HEADER_END@
#
#######################################################################

#######################################################################
# $SiLK: plugin.py 13562 2009-02-16 18:39:21Z mwd $
#######################################################################

##########################################################################
# Plugin-related code

__all__ = ["register_plugin_field"]

_plugin_data = []
_plugin_fields = {'text_len': int,
                  'rec_to_text': 1,
                  'bin_len': int,
                  'rec_to_bin': 1,
                  'bin_to_text': 1}

_plugin_reqs = {'cut':  ['name', 'text_len', 'rec_to_text'],
                'sort': ['name', 'bin_len', 'rec_to_bin'],
                'uniq': ['name', 'text_len', 'bin_len',
                         'rec_to_bin', 'bin_to_text']}


def _get_plugin_data(plugin_type):
    data = []
    reqs = _plugin_reqs[plugin_type]
    for (i, field) in enumerate(_plugin_data):
        values = [field[x] for x in reqs if x in field]
        if len(values) == len(reqs):
            data.append(tuple(values))
    if not data:
        raise RuntimeError("No valid fields for %s Python plugin" %
                           plugin_type)
    return data

def register_plugin_field(name, **kwds):
    global _plugin_data

    if not isinstance(name, str):
        raise TypeError("Name must be a string")

    for val in _plugin_data:
        if val['name'] == name:
            raise ValueError("A field '%s' has already been registered", name)

    # For backwards compatability, allow field_len to be used as text_len
    if 'field_len' in kwds and 'text_len' not in kwds:
        kwds['text_len'] = kwds['field_len']
        del kwds['field_len']
    # Add 1 to text len for zero byte
    if 'text_len' in kwds:
        kwds['text_len'] += 1

    for (kwd, val) in kwds.iteritems():
        if kwd not in _plugin_fields:
            raise ValueError("Illegal argument name '%s'" % kwd)
        field_spec = _plugin_fields[kwd]
        if isinstance(field_spec, type):
            if not isinstance(val, field_spec):
                raise TypeError("Argument '%s' must be of type %s" %
                                (kwd, field_spec))
        elif not callable(val):
            raise TypeError("Argument '%s' must be a function of %d arguments"
                            % (kwd, field_spec))

    kwds['name'] = name
    _plugin_data.append(kwds)

_register_plugin_field = register_plugin_field

import os
import sys
import traceback

_programname = None

def _no_traceback_exception(t, value, tb):
    global _programname
    t = str(t).split('.')[-1]
    if _programname:
        printname = _programname
    else:
        try:
            printname = sys.argv[0]
        except:
            printname = "python"
    sys.stderr.write(printname + ": PySiLK plugin: " + t)
    if value and str(value):
        sys.stderr.write(": " + str(value))
    sys.stderr.write("\n")
    if os.getenv("SILK_PYTHON_TRACEBACK"):
        traceback.print_tb(tb)

def _init_silkpython_plugin(name):
    global _programname
    _programname = name
    sys.excepthook = _no_traceback_exception
